@@ -371,8 +371,7 @@ describe 'apache::mod::php', type: :class do
         'class { "apache": mpm_module => worker, }'
       end
 
-      it 'raises an error' do # rubocop:disable RSpec/MultipleExpectations
-        # rubocop:disable RSpec/NamedSubject
+      it 'raises an error' do
         expect { expect(subject).to contain_apache__mod('php5') }.to raise_error Puppet::Error, %r{mpm_module => 'prefork' or mpm_module => 'itk'}
       end
     end
